@@ -17,7 +17,7 @@
 ################################################################################
 # Author : Mauricio Zambrano-Bigiarini                                         #  
 # Started: 03-Feb-2012                                                         #
-# Updates: 15-Feb-2012 ; 22-Feb-2012 ; 28-Jun-2012                             #        
+# Updates: 15-Feb-2012 ; 22-Feb-2012 ; 28-Jun-2012 ; 26-Sep-2012               #        
 ################################################################################
 
 plot_out <- function(sim, obs, 
@@ -75,24 +75,22 @@ plot_out <- function(sim, obs,
       stop("Invalid argument: 'length(dates) != length(sim)' ", length(dates), "!=", nouts, " !!")
   } #IF end 
   
-  # Checking 'MinMax'
-  if ( (ptype=="corr") | (ptype=="ts") ) {
-    if ( is.null(MinMax) ) {
-       stop("Missing argument: 'MinMax' must be provided !!")
-    } else if ( !(MinMax %in% c("min", "max")) )
-             stop("Invalid argument: 'MinMax' must be in c('min', 'max')")
-  } # IF end
+#  # Checking 'MinMax'
+#  if ( is.null(MinMax) ) {
+#     stop("Missing argument: 'MinMax' must be provided !!")
+#  } else if ( !(MinMax %in% c("min", "max")) )
+#           stop("Invalid argument: 'MinMax' must be in c('min', 'max')")
   
   # Checking 'hydroGOF' pacakge when ptype=="ts"
   if (ptype=="ts") {
-   if (!require(hydroGOF))
+   if ( is.na( match("hydroGOF", installed.packages()[,"Package"] ) ) )
      stop("Invalid argument: You don't have the 'hydroGOF' package => You can not use 'ptype='ts' !!")
   } # IF end
            
   # Checking 'class(sim)'    
   if ( (ptype=="corr") | (ptype=="ts") ) {
-    if (class(sim) != "numeric")
-      stop("Invalid argument: 'class(sim)' must be numeric for 'ptype' in c('corr', 'ts') !!")
+    if ( !(class(sim) %in% c("numeric", "integer") ) )
+      stop("Invalid argument: 'class(sim)' must be in c('numeric', 'integer') for 'ptype' in c('corr', 'ts') !!")
   } else if ( (ptype=="ecdf") | (ptype=="quant2ecdf") ) {
     # if ( (class(sim) != "matrix") & (class(sim) != "data.frame") )
     #  stop("Invalid argument: 'class(sim)' must be in c('matrix', 'data.frame') for 'ptype' in c('ecdf', 'quant2ecdf') !!")
